<?php

namespace Wincher;

use GuzzleHttp\Exception\GuzzleException;

class DashboardPage
{
    /**
     * @var Plugin
     */
    protected $plugin;

    /**
     * DashboardPage constructor.
     *
     * @param Plugin $plugin
     *
     * @throws GuzzleException
     */
    public function __construct(Plugin $plugin)
    {
        $this->plugin = $plugin;
        $this->enqueueAssets();

        $resp = $this->plugin->getWincherClient()->getAccount();
        if ($resp['status'] === 200 && get_option('wincher_account_type') !== $resp['data']['account_type']) {
            update_option('wincher_account_type', $resp['data']['account_type']);
        }
    }

    /**
     * Returns the name of this page.
     *
     * @return string
     */
    public function getName()
    {
        return 'dashboard';
    }

    /**
     * Returns an array of built assets to load.
     *
     * @return array
     */
    public function getAssets()
    {
        return [
            'dashboard.js',
            'dashboard.css'
        ];
    }

    /**
     * Renders the page contents.
     */
    public function render()
    {
        $slug = Plugin::SLUG;
        $id = "{$slug}-{$this->getName()}-root";

        ?>
        <div id="<?php echo $id; ?>"></div>
        <?php
    }

    /**
     * Enqueues the built assets for this page.
     */
    protected function enqueueAssets()
    {
        $prefix = '';
        if (file_exists(WINCHER_PLUGIN_BASE_PATH . 'build')) {
            $prefix = 'build/';
        }
        $manifest = json_decode(file_get_contents(WINCHER_PLUGIN_BASE_PATH . $prefix . 'assets/manifest.json'), true);

        foreach ($this->getAssets() as $asset) {
            if (!isset($manifest[$asset])) {
                continue;
            }

            $url = $manifest[$asset];

            // Resolve the correct URL unless we were given a full URL.
            if (strpos($url, 'http://') === false) {
                $url = WINCHER_PLUGIN_BASE_URL . $prefix . 'assets/' . $url;
            }

            if (strpos($url, '.js') !== false) {
                wp_enqueue_script(Plugin::SLUG . $asset, $url);
            } else {
                wp_enqueue_style(Plugin::SLUG . $asset, $url);
            }
        }
    }
}
